/*
 * Version: @(#) 1.3 SSOA/ws/code/soa.sca.container.spi/src/com/ibm/wsspi/container/binding/BindingManager.java, WAS.soa.sca.container.spi, SCA101.SSOA, cf051018.03 09/08/10 01:52:38 [5/10/10 22:21:28]
 *
 * COMPONENT_NAME: <WAS.soa.sca.container.spi>
 *
 * IBM Confidential OCO Source Material
 * 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N01, 5733-W61 (C) COPYRIGHT International Business Machines Corp. 2009
 * The source code for this program is not published or otherwise divested
 * of its trade secrets, irrespective of what has been deposited with the
 * U.S. Copyright Office.
 *
 *
 * HISTORY
 * CMVC Ref         Date      Who       Description
 * --------------- 	--------- --------- --------------------------------------------
 * F00CmnContainer  20090605  srashmi   Initial Implementation
 * F003438-14830    20090806  srashmi   ServiceProvider uses generic operation type O 
 */

package com.ibm.wsspi.container.binding;


/**
 * Manages the ServiceProviders for a given Binding.  Each ServiceProvider is identified by the
 * Service which it configures.
 * @ibm-spi
 */
public interface BindingManager <B extends Binding, I, O>{
	
    /**
     * Adds a service endpoint given a service and binding. This method gets called typically from
     * bindingProvider start(). This  starts the ServiceProvider,  creates/start the endpoint and
     * creates the invoker for each operation.  ServiceProviders are cached in memory based on 
     * serviceName/bindingName
     *     
     * @param service name
     * @param binding
     * @param ServiceProvider
     * 
     */
	void add(Service service, B binding, ServiceProvider<B, I, O> provider) throws EndpointException;
	
    /**
     * Removes the service endpoint given a service and binding. This method gets called typically from
     * bindingProvider stop(). This method stops the ServiceProvider,  deactivates/stops the endpoint
     * and does necessary cleanup. 
     * 
     *     
     * @param service name
     * @param binding
     * 
     */
	ServiceProvider<B, I, O> remove(Service service, B binding) throws EndpointException;
	
    /**
     * Gets the ServiceProvider given a service and binding.  
     *     
     * @param service 
     * @param binding
     * @return serviceProvider
     * 
     */
	ServiceProvider<B, I, O> get(Service service, B binding);
}
