// IBM Confidential OCO Source Material
// 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N01, 5722-WE2 (C) COPYRIGHT International Business Machines Corp. 2009
// The source code for this program is not published or otherwise divested
// of its trade secrets, irrespective of what has been deposited with the
// U.S. Copyright Office.

package com.ibm.wsspi.i18n.context.util;

import java.util.logging.Logger;
import java.util.logging.Level;

import com.ibm.ws.i18n.context.I18nAttr;
import com.ibm.ws.i18n.context.I18nService;
import com.ibm.ws.i18n.context.LocalThreadContext_20;
import com.ibm.ws.i18n.context.ThreadContextManager;
import com.ibm.ws.container.util.SCASPILogger;

/**
 * Provide a utility method to programmatically set the i18n policy to AMI.
 * This might be used if an application contains no EJBs or servlets,
 * but still needs to set the i18n service's locale for future use.
 * @ibm-spi
 */
public class InternationalizationServiceUtil {

	private static final String className="com.ibm.wsspi.i18n.context.util.InternationalizationServiceUtil";
	private static final Logger logger = SCASPILogger.getLogger(className);

	static private void debug(Level level, String methodName, String msg){
		if (logger.isLoggable(level)){
			logger.logp(level, className, methodName, msg);
		}
	}
	/**
	* utility method to force AMI on this thread
	*/
	public static void forceAMIPolicy(){

		debug(Level.FINEST,"forceAMIPolicy","Entry");
	    // <1> Check the state.
	    if (I18nService.STARTED != I18nService.getState ())
	    {
	    	debug(Level.FINEST,"forceAMIPolicy","Internationalization Service is not started on " + I18nService.getProcessName () + ". No action taken.");

	    } else {

		    //  <2> Get the current context.
		    ThreadContextManager threadContextManager = ThreadContextManager.getInstance ();
		    LocalThreadContext_20 currentContext = (LocalThreadContext_20)threadContextManager.getCurrentContext ();
		    if (null == currentContext)
			  {
		    	debug(Level.FINEST,"forceAMIPolicy","currentContext was null, setting policy to AMI.");
			    currentContext = LocalThreadContext_20.newInstance (null, null, null, null, I18nAttr.AMI_RUN_AS_SERVER);
			  }
		    // <3> set context to AMI
		    currentContext.setI18nAttr (I18nAttr.AMI_RUN_AS_SERVER);
		    threadContextManager.setCurrentContext (currentContext);
		    debug(Level.FINEST,"forceAMIPolicy","set current context to AMI_RUN_AS_SERVER.");


	    }
	    debug(Level.FINEST,"forceAMIPolicy","Exit.");
	}
}
